package com.sun.java.swing.plaf.motif;

import java.awt.Rectangle;
import java.awt.Graphics;
import javax.swing.UIManager;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import java.awt.Color;
import javax.swing.plaf.basic.BasicTabbedPaneUI;

public class MotifTabbedPaneUI extends BasicTabbedPaneUI
{
    protected Color unselectedTabBackground;
    protected Color unselectedTabForeground;
    protected Color unselectedTabShadow;
    protected Color unselectedTabHighlight;
    
    public MotifTabbedPaneUI() {
    }
    
    public static ComponentUI createUI(JComponent component) {
        return new MotifTabbedPaneUI();
    }
    
    @Override
    protected void installDefaults() {
        super.installDefaults();
        this.unselectedTabBackground = UIManager.getColor("TabbedPane.unselectedTabBackground");
        this.unselectedTabForeground = UIManager.getColor("TabbedPane.unselectedTabForeground");
        this.unselectedTabShadow = UIManager.getColor("TabbedPane.unselectedTabShadow");
        this.unselectedTabHighlight = UIManager.getColor("TabbedPane.unselectedTabHighlight");
    }
    
    @Override
    protected void uninstallDefaults() {
        super.uninstallDefaults();
        this.unselectedTabBackground = null;
        this.unselectedTabForeground = null;
        this.unselectedTabShadow = null;
        this.unselectedTabHighlight = null;
    }
    
    @Override
    protected void paintContentBorderTopEdge(Graphics graphics, int n, int tabIndex, int n2, int n3, int n4, int n5) {
        Rectangle rectangle = (tabIndex < 0) ? null : this.getTabBounds(tabIndex, this.calcRect);
        graphics.setColor(this.lightHighlight);
        if (n != 1 || tabIndex < 0 || rectangle.x < n2 || rectangle.x > n2 + n4) {
            graphics.drawLine(n2, n3, n2 + n4 - 2, n3);
        }
        else {
            graphics.drawLine(n2, n3, rectangle.x - 1, n3);
            if (rectangle.x + rectangle.width < n2 + n4 - 2) {
                graphics.drawLine(rectangle.x + rectangle.width, n3, n2 + n4 - 2, n3);
            }
        }
    }
    
    @Override
    protected void paintContentBorderBottomEdge(Graphics graphics, int n, int tabIndex, int n2, int n3, int n4, int n5) {
        Rectangle rectangle = (tabIndex < 0) ? null : this.getTabBounds(tabIndex, this.calcRect);
        graphics.setColor(this.shadow);
        if (n != 3 || tabIndex < 0 || rectangle.x < n2 || rectangle.x > n2 + n4) {
            graphics.drawLine(n2 + 1, n3 + n5 - 1, n2 + n4 - 1, n3 + n5 - 1);
        }
        else {
            graphics.drawLine(n2 + 1, n3 + n5 - 1, rectangle.x - 1, n3 + n5 - 1);
            if (rectangle.x + rectangle.width < n2 + n4 - 2) {
                graphics.drawLine(rectangle.x + rectangle.width, n3 + n5 - 1, n2 + n4 - 2, n3 + n5 - 1);
            }
        }
    }
    
    @Override
    protected void paintContentBorderRightEdge(Graphics graphics, int n, int tabIndex, int n2, int n3, int n4, int n5) {
        Rectangle rectangle = (tabIndex < 0) ? null : this.getTabBounds(tabIndex, this.calcRect);
        graphics.setColor(this.shadow);
        if (n != 4 || tabIndex < 0 || rectangle.y < n3 || rectangle.y > n3 + n5) {
            graphics.drawLine(n2 + n4 - 1, n3 + 1, n2 + n4 - 1, n3 + n5 - 1);
        }
        else {
            graphics.drawLine(n2 + n4 - 1, n3 + 1, n2 + n4 - 1, rectangle.y - 1);
            if (rectangle.y + rectangle.height < n3 + n5 - 2) {
                graphics.drawLine(n2 + n4 - 1, rectangle.y + rectangle.height, n2 + n4 - 1, n3 + n5 - 2);
            }
        }
    }
    
    @Override
    protected void paintTabBackground(Graphics graphics, int n, int index, int n2, int n3, int n4, int n5, boolean b) {
        graphics.setColor(b ? this.tabPane.getBackgroundAt(index) : this.unselectedTabBackground);
        switch (n) {
            case 2: {
                graphics.fillRect(n2 + 1, n3 + 1, n4 - 1, n5 - 2);
                break;
            }
            case 4: {
                graphics.fillRect(n2, n3 + 1, n4 - 1, n5 - 2);
                break;
            }
            case 3: {
                graphics.fillRect(n2 + 1, n3, n4 - 2, n5 - 3);
                graphics.drawLine(n2 + 2, n3 + n5 - 3, n2 + n4 - 3, n3 + n5 - 3);
                graphics.drawLine(n2 + 3, n3 + n5 - 2, n2 + n4 - 4, n3 + n5 - 2);
                break;
            }
            default: {
                graphics.fillRect(n2 + 1, n3 + 3, n4 - 2, n5 - 3);
                graphics.drawLine(n2 + 2, n3 + 2, n2 + n4 - 3, n3 + 2);
                graphics.drawLine(n2 + 3, n3 + 1, n2 + n4 - 4, n3 + 1);
                break;
            }
        }
    }
    
    @Override
    protected void paintTabBorder(Graphics graphics, int n, int n2, int n3, int n4, int n5, int n6, boolean b) {
        graphics.setColor(b ? this.lightHighlight : this.unselectedTabHighlight);
        switch (n) {
            case 2: {
                graphics.drawLine(n3, n4 + 2, n3, n4 + n6 - 3);
                graphics.drawLine(n3 + 1, n4 + 1, n3 + 1, n4 + 2);
                graphics.drawLine(n3 + 2, n4, n3 + 2, n4 + 1);
                graphics.drawLine(n3 + 3, n4, n3 + n5 - 1, n4);
                graphics.setColor(b ? this.shadow : this.unselectedTabShadow);
                graphics.drawLine(n3 + 1, n4 + n6 - 3, n3 + 1, n4 + n6 - 2);
                graphics.drawLine(n3 + 2, n4 + n6 - 2, n3 + 2, n4 + n6 - 1);
                graphics.drawLine(n3 + 3, n4 + n6 - 1, n3 + n5 - 1, n4 + n6 - 1);
                break;
            }
            case 4: {
                graphics.drawLine(n3, n4, n3 + n5 - 3, n4);
                graphics.setColor(b ? this.shadow : this.unselectedTabShadow);
                graphics.drawLine(n3 + n5 - 3, n4, n3 + n5 - 3, n4 + 1);
                graphics.drawLine(n3 + n5 - 2, n4 + 1, n3 + n5 - 2, n4 + 2);
                graphics.drawLine(n3 + n5 - 1, n4 + 2, n3 + n5 - 1, n4 + n6 - 3);
                graphics.drawLine(n3 + n5 - 2, n4 + n6 - 3, n3 + n5 - 2, n4 + n6 - 2);
                graphics.drawLine(n3 + n5 - 3, n4 + n6 - 2, n3 + n5 - 3, n4 + n6 - 1);
                graphics.drawLine(n3, n4 + n6 - 1, n3 + n5 - 3, n4 + n6 - 1);
                break;
            }
            case 3: {
                graphics.drawLine(n3, n4, n3, n4 + n6 - 3);
                graphics.drawLine(n3 + 1, n4 + n6 - 3, n3 + 1, n4 + n6 - 2);
                graphics.drawLine(n3 + 2, n4 + n6 - 2, n3 + 2, n4 + n6 - 1);
                graphics.setColor(b ? this.shadow : this.unselectedTabShadow);
                graphics.drawLine(n3 + 3, n4 + n6 - 1, n3 + n5 - 4, n4 + n6 - 1);
                graphics.drawLine(n3 + n5 - 3, n4 + n6 - 2, n3 + n5 - 3, n4 + n6 - 1);
                graphics.drawLine(n3 + n5 - 2, n4 + n6 - 3, n3 + n5 - 2, n4 + n6 - 2);
                graphics.drawLine(n3 + n5 - 1, n4, n3 + n5 - 1, n4 + n6 - 3);
                break;
            }
            default: {
                graphics.drawLine(n3, n4 + 2, n3, n4 + n6 - 1);
                graphics.drawLine(n3 + 1, n4 + 1, n3 + 1, n4 + 2);
                graphics.drawLine(n3 + 2, n4, n3 + 2, n4 + 1);
                graphics.drawLine(n3 + 3, n4, n3 + n5 - 4, n4);
                graphics.setColor(b ? this.shadow : this.unselectedTabShadow);
                graphics.drawLine(n3 + n5 - 3, n4, n3 + n5 - 3, n4 + 1);
                graphics.drawLine(n3 + n5 - 2, n4 + 1, n3 + n5 - 2, n4 + 2);
                graphics.drawLine(n3 + n5 - 1, n4 + 2, n3 + n5 - 1, n4 + n6 - 1);
                break;
            }
        }
    }
    
    @Override
    protected void paintFocusIndicator(Graphics graphics, int n, Rectangle[] array, int n2, Rectangle rectangle, Rectangle rectangle2, boolean b) {
        Rectangle rectangle3 = array[n2];
        if (this.tabPane.hasFocus() && b) {
            graphics.setColor(this.focus);
            int x;
            int y;
            int width;
            int height;
            switch (n) {
                case 2: {
                    x = rectangle3.x + 3;
                    y = rectangle3.y + 3;
                    width = rectangle3.width - 6;
                    height = rectangle3.height - 7;
                    break;
                }
                case 4: {
                    x = rectangle3.x + 2;
                    y = rectangle3.y + 3;
                    width = rectangle3.width - 6;
                    height = rectangle3.height - 7;
                    break;
                }
                case 3: {
                    x = rectangle3.x + 3;
                    y = rectangle3.y + 2;
                    width = rectangle3.width - 7;
                    height = rectangle3.height - 6;
                    break;
                }
                default: {
                    x = rectangle3.x + 3;
                    y = rectangle3.y + 3;
                    width = rectangle3.width - 7;
                    height = rectangle3.height - 6;
                    break;
                }
            }
            graphics.drawRect(x, y, width, height);
        }
    }
    
    @Override
    protected int getTabRunIndent(int n, int n2) {
        return n2 * 3;
    }
    
    @Override
    protected int getTabRunOverlay(int n) {
        this.tabRunOverlay = ((n == 2 || n == 4) ? ((int)Math.round((double)(float)this.maxTabWidth * 0.1)) : ((int)Math.round((double)(float)this.maxTabHeight * 0.22)));
        switch (n) {
            case 2: {
                if (this.tabRunOverlay > this.tabInsets.right - 2) {
                    this.tabRunOverlay = this.tabInsets.right - 2;
                    break;
                }
                break;
            }
            case 4: {
                if (this.tabRunOverlay > this.tabInsets.left - 2) {
                    this.tabRunOverlay = this.tabInsets.left - 2;
                    break;
                }
                break;
            }
            case 1: {
                if (this.tabRunOverlay > this.tabInsets.bottom - 2) {
                    this.tabRunOverlay = this.tabInsets.bottom - 2;
                    break;
                }
                break;
            }
            case 3: {
                if (this.tabRunOverlay > this.tabInsets.top - 2) {
                    this.tabRunOverlay = this.tabInsets.top - 2;
                    break;
                }
                break;
            }
        }
        return this.tabRunOverlay;
    }
}
